@@ -8,11 +8,21 @@ test_elementtree
 """
 
 
-import unittest, doctest
+import unittest, doctest, copy, sys
 
 from common_imports import etree, StringIO, HelperTestCase, fileInTestDir
 from common_imports import SillyFileLike, canonicalize
 
+print
+print "TESTED VERSION:"
+print "    Python:           ", sys.version_info
+print "    lxml.etree:       ", etree.LXML_VERSION
+print "    libxml used:      ", etree.LIBXML_VERSION
+print "    libxml compiled:  ", etree.LIBXML_COMPILED_VERSION
+print "    libxslt used:     ", etree.LIBXSLT_VERSION
+print "    libxslt compiled: ", etree.LIBXSLT_COMPILED_VERSION
+print
+
 class ETreeOnlyTestCase(HelperTestCase):
     """Tests only for etree, not ElementTree"""
     etree = etree
@@ -82,6 +92,29 @@ class ETreeOnlyTestCase(HelperTestCase):
         self.assertEquals(root[0].target, "mypi")
         self.assertEquals(root[0].text, "my test ")
 
+    def test_deepcopy_pi(self):
+        # previously caused a crash
+        ProcessingInstruction = self.etree.ProcessingInstruction
+        
+        a = ProcessingInstruction("PI", "ONE")
+        b = copy.deepcopy(a)
+        b.text = "ANOTHER"
+
+        self.assertEquals('ONE',     a.text)
+        self.assertEquals('ANOTHER', b.text)
+
+    def test_deepcopy_comment(self):
+        # previously caused a crash
+        # not supported by ET!
+        Comment = self.etree.Comment
+        
+        a = Comment("ONE")
+        b = copy.deepcopy(a)
+        b.text = "ANOTHER"
+
+        self.assertEquals('ONE',     a.text)
+        self.assertEquals('ANOTHER', b.text)
+
     def test_attribute_set(self):
         # ElementTree accepts arbitrary attribute values
         # lxml.etree allows only strings
@@ -1195,6 +1228,22 @@ class ETreeXIncludeTestCase(HelperTestCase):
         self.assertEquals(
             'a',
             tree.getroot()[1].tag)
+
+    def test_xinclude_text(self):
+        filename = fileInTestDir('test_broken.xml')
+        root = etree.XML('''\
+        <doc xmlns:xi="http://www.w3.org/2001/XInclude">
+          <xi:include href="%s" parse="text"/>
+        </doc>
+        ''' % filename)
+        old_text = root.text
+        content = open(filename).read()
+        old_tail = root[0].tail
+
+        etree.ElementTree(root).xinclude()
+        self.assertEquals(old_text + content + old_tail,
+                          root.text)
+        
         
 class ETreeC14NTestCase(HelperTestCase):
     def test_c14n(self):
