@@ -21,6 +21,15 @@ class ETreeNamespaceClassesTestCase(HelperTestCase):
         def bluff(self):
             return u'bluff'
 
+    def setUp(self):
+        parser = etree.XMLParser()
+        parser.setElementClassLookup(
+            etree.ElementNamespaceClassLookup() )
+        etree.setDefaultParser(parser)
+
+    def tearDown(self):
+        etree.setDefaultParser()
+
     def test_registry(self):
         ns = etree.Namespace(u'ns01')
         ns[u'maeh'] = self.maeh_class
@@ -144,31 +153,12 @@ class ETreeNamespaceClassesTestCase(HelperTestCase):
         etree.Namespace(None).clear()
         etree.Namespace(u'ns30').clear()
 
-    def test_default_element_class(self):
-        class local_default_class(etree.ElementBase):
-            pass
-
-        try:
-            etree.setDefaultElementClass(local_default_class)
-            self.assert_(isinstance(etree.Element("test"),
-                                    local_default_class))
-            self.assert_(isinstance(etree.Element("{http://myns}test"),
-                                    local_default_class))
-
-            etree.setDefaultElementClass()
-            self.assertFalse(isinstance(etree.Element("test"),
-                                        local_default_class))
-            self.assertFalse(isinstance(etree.Element("{http://myns}test"),
-                                        local_default_class))
-        finally:
-            etree.setDefaultElementClass()
-
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTests([unittest.makeSuite(ETreeNamespaceClassesTestCase)])
     optionflags = doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS
     suite.addTests(
-        [doctest.DocFileSuite('../../../doc/namespace_extensions.txt',
+        [doctest.DocFileSuite('../../../doc/element_classes.txt',
                               optionflags=optionflags)],
         )
     return suite
